@@ -23,82 +23,71 @@ from aliyunsdkpolardb.endpoint import endpoint_data
 class CreateDatabaseRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'polardb', '2017-08-01', 'CreateDatabase','polardb')
+		RpcRequest.__init__(self, 'polardb', '2017-08-01', 'CreateDatabase')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_AccountPrivilege(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_AccountPrivilege(self): # String
 		return self.get_query_params().get('AccountPrivilege')
 
-	def set_AccountPrivilege(self,AccountPrivilege):
-		self.add_query_param('AccountPrivilege',AccountPrivilege)
-
-	def get_AccountName(self):
+	def set_AccountPrivilege(self, AccountPrivilege):  # String
+		self.add_query_param('AccountPrivilege', AccountPrivilege)
+	def get_AccountName(self): # String
 		return self.get_query_params().get('AccountName')
 
-	def set_AccountName(self,AccountName):
-		self.add_query_param('AccountName',AccountName)
-
-	def get_DBDescription(self):
+	def set_AccountName(self, AccountName):  # String
+		self.add_query_param('AccountName', AccountName)
+	def get_DBDescription(self): # String
 		return self.get_query_params().get('DBDescription')
 
-	def set_DBDescription(self,DBDescription):
-		self.add_query_param('DBDescription',DBDescription)
-
-	def get_ResourceOwnerAccount(self):
+	def set_DBDescription(self, DBDescription):  # String
+		self.add_query_param('DBDescription', DBDescription)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_DBClusterId(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_DBClusterId(self): # String
 		return self.get_query_params().get('DBClusterId')
 
-	def set_DBClusterId(self,DBClusterId):
-		self.add_query_param('DBClusterId',DBClusterId)
-
-	def get_OwnerAccount(self):
+	def set_DBClusterId(self, DBClusterId):  # String
+		self.add_query_param('DBClusterId', DBClusterId)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_OwnerId(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_Collate(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_Collate(self): # String
 		return self.get_query_params().get('Collate')
 
-	def set_Collate(self,Collate):
-		self.add_query_param('Collate',Collate)
-
-	def get_DBName(self):
+	def set_Collate(self, Collate):  # String
+		self.add_query_param('Collate', Collate)
+	def get_DBName(self): # String
 		return self.get_query_params().get('DBName')
 
-	def set_DBName(self,DBName):
-		self.add_query_param('DBName',DBName)
-
-	def get_Ctype(self):
+	def set_DBName(self, DBName):  # String
+		self.add_query_param('DBName', DBName)
+	def get_Ctype(self): # String
 		return self.get_query_params().get('Ctype')
 
-	def set_Ctype(self,Ctype):
-		self.add_query_param('Ctype',Ctype)
-
-	def get_CharacterSetName(self):
+	def set_Ctype(self, Ctype):  # String
+		self.add_query_param('Ctype', Ctype)
+	def get_CharacterSetName(self): # String
 		return self.get_query_params().get('CharacterSetName')
 
-	def set_CharacterSetName(self,CharacterSetName):
-		self.add_query_param('CharacterSetName',CharacterSetName)
\ No newline at end of file
+	def set_CharacterSetName(self, CharacterSetName):  # String
+		self.add_query_param('CharacterSetName', CharacterSetName)
